Flow specific modules
---------------------

.. toctree::
   IMTreatment.boundary_layer.boundary_layer
   IMTreatment.potential_flow.potential_flow
   IMTreatment.vortex_creation.vortex_creation
   IMTreatment.vortex_detection.vortex_detection
   IMTreatment.vortex_criterions.vortex_criterions
   IMTreatment.vortex_properties.vortex_properties
